This library is for internal use for organization.

NDAx_decoder is the Package to decode the NDAx file generated by BTS Software.

Following Functions are the key feature of Package.

1.	get_barcode
    Args:(ndax file path)

    It first search for Barcode tag in Testinfo.xml if not found search all the xml file.

2.	get_cycle
    Args: (df)

    Returns the cycle wise data

3.	get_process_name 
    Args:(ndax file path)

    Returns Recipe Name reads the ‘StepName’ from TestInfo.xml. 

4.	get_recipe 
    Args: (df)

    Returns the recipe or test instruction set at the time of test like rest time, voltage limits, etc

5.	get_records
    Args: (nda file path)

    Returns the record-wise data frame from ndc file.

6.	get_remarks
    Args: (ndax file path)

    While performing the testing the cell, we might want to note some specific information, that is get store as remark, and can be seen while retrieving the data from ndax file. 

7.	get_start_time
    Args: (nda file path)

    It returns Start Time for passed NDA file Recipe

8.	get_step
    Args: (df)
        
    It returns step-by-step data that is exactly the same as the cycle sheet in the test's excel file after passing an NDAx file or the records data.



